package com.tanpu.fund.entity.generator;

import java.math.BigDecimal;
import java.util.Date;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * 基金历史业绩
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class FundCount {
    private String id;

    /**
     * 基金id
     */
    private String fundId;

    /**
     * 基金策略分类
     */
    private Integer strategy;

    /**
     * 融智子策略分类:1010-主观多头 1020-股票多空 1030-量化多头 2010-宏观策略 3010-主观趋势 3020-主观套利 3030-量化趋势 3040-量化套利 3050-管理期货复合 4010-并购重组 4020-定向增发 4030-大宗交易 4040-事件驱动复合 5010-股票市场中性 5020-套利 5030-相对价值复合 6010-纯债策略 6020-强债策略 6030-固收复合 7010-MOM 7020-FOF 8010-主观多策略 8020-量化多策略 -1-其他策略'
     */
    private Integer substrategy;

    /**
     * 基金成立日期
     */
    private Date inceptionDate;

    /**
     * 是否可预约 0:不可预约 1:可预约
     */
    private Integer type;

    /**
     * 截至日期
     */
    private Date endDate;

    /**
     * 最近累计净值日期
     */
    private Date priceDate;

    /**
     * 单位净值
     */
    private BigDecimal netNav;

    /**
     * 最近累计净值
     */
    private BigDecimal cumulativeNav;

    /**
     * 最近一天收益率
     */
    private BigDecimal ret1day;

    /**
     * 最近一天基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret1dayBm1;

    /**
     * 最近一个周收益率
     */
    private BigDecimal ret1w;

    /**
     * 最近一个周基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret1wBm1;

    /**
     * 最近一个月收益率
     */
    private BigDecimal ret1m;

    /**
     * 最近一个月基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret1mBm1;

    /**
     * 最近三个月收益率
     */
    private BigDecimal ret3m;

    /**
     * 最近三个月基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret3mBm1;

    /**
     * 最近半年收益率
     */
    private BigDecimal ret6m;

    /**
     * 最近半年基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret6mBm1;

    /**
     * 最近一年收益率
     */
    private BigDecimal ret1y;

    /**
     * 最近一年基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret1yBm1;

    /**
     * 最近两年收益率
     */
    private BigDecimal ret2y;

    /**
     * 最近两年基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret2yBm1;

    /**
     * 最近两年收益率（年化）
     */
    private BigDecimal ret2yA;

    /**
     * 最近两年基准指数收益率（年化），基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret2yBm1A;

    /**
     * 最近三年收益率
     */
    private BigDecimal ret3y;

    /**
     * 最近三年基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret3yBm1;

    /**
     * 最近三年收益率（年化）
     */
    private BigDecimal ret3yA;

    /**
     * 最近三年基准指数收益率（年化），基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret3yBm1A;

    /**
     * 最近四年收益率
     */
    private BigDecimal ret4y;

    /**
     * 最近四年基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret4yBm1;

    /**
     * 最近四年收益率（年化）
     */
    private BigDecimal ret4yA;

    /**
     * 最近四年基准指数收益率（年化），基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret4yBm1A;

    /**
     * 最近五年收益率
     */
    private BigDecimal ret5y;

    /**
     * 最近五年基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret5yBm1;

    /**
     * 最近五年收益率（年化）
     */
    private BigDecimal ret5yA;

    /**
     * 最近五年基准指数收益率（年化），基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal ret5yBm1A;

    /**
     * 今年以来收益率
     */
    private BigDecimal retYtd;

    /**
     * 今年以来基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal retYtdBm1;

    /**
     * 成立以来收益率
     */
    private BigDecimal retIncep;

    /**
     * 成立以来基准指数收益率，基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal retIncepBm1;

    /**
     * 成立以来收益率（年化）
     */
    private BigDecimal retIncepA;

    /**
     * 成立以来基准指数收益率（年化），基准指数bm1=沪深300（取决于基金设定的基准指数）
     */
    private BigDecimal retIncepBm1A;

    private BigDecimal sharperatio1m;

    private BigDecimal sharperatio3m;

    private BigDecimal sharperatio6m;

    /**
     * 最近一年的夏普比率
     */
    private BigDecimal sharperatio1y;

    /**
     * 最近两年的夏普比率
     */
    private BigDecimal sharperatio2y;

    /**
     * 最近三年的夏普比率
     */
    private BigDecimal sharperatio3y;

    /**
     * 最近四年的夏普比率
     */
    private BigDecimal sharperatio4y;

    /**
     * 最近五年的夏普比率
     */
    private BigDecimal sharperatio5y;

    private BigDecimal sharperatioYtd;

    /**
     * 成立以来的夏普比率
     */
    private BigDecimal sharperatioIncep;

    private BigDecimal stddev1m;

    private BigDecimal stddev3m;

    private BigDecimal stddev6m;

    /**
     * 最近一年的年化波动率
     */
    private BigDecimal stddev1y;

    /**
     * 最近两年的年化波动率
     */
    private BigDecimal stddev2y;

    /**
     * 最近三年的年化波动率
     */
    private BigDecimal stddev3y;

    /**
     * 最近四年的年化波动率
     */
    private BigDecimal stddev4y;

    /**
     * 最近五年的年化波动率
     */
    private BigDecimal stddev5y;

    /**
     * 最近十年的年化波动率
     */
    private BigDecimal stddev10y;

    /**
     * 成立以来的年化波动率
     */
    private BigDecimal stddevIncep;

    /**
     * 今年以来的年化波动率
     */
    private BigDecimal stddevYtd;

    /**
     * 最近一年的最大回撤
     */
    private BigDecimal maxdrawdown1y;

    /**
     * 最近两年的最大回撤
     */
    private BigDecimal maxdrawdown2y;

    /**
     * 最近四年的最大回撤
     */
    private BigDecimal maxdrawdown3y;

    /**
     * 最近四年的最大回撤
     */
    private BigDecimal maxdrawdown4y;

    /**
     * 最近五年的最大回撤
     */
    private BigDecimal maxdrawdown5y;

    /**
     * 最近十年的最大回撤
     */
    private BigDecimal maxdrawdown10y;

    /**
     * 成立以来的最大回撤
     */
    private BigDecimal maxdrawdownIncep;

    private BigDecimal maxdrawdown1m;

    private BigDecimal maxdrawdown3m;

    private BigDecimal maxdrawdown6m;

    private BigDecimal maxdrawdownYtd;

    /**
     * 数据来源 1:tanpu，2:私募排排 3:指数
     */
    private Integer dataSources;

    private Date updateTime;

    private Date createTime;

    /**
     * 0:待上架  1：已上架 2：已下架
     */
    private Integer status;

    /**
     * 排序
     */
    private Integer sort;

    private Integer deleteTag;

    /**
     * 卡玛比率
     */
    private BigDecimal calmarRatio;

    /**
     * alpha
     */
    private BigDecimal alpha;

    /**
     * beta
     */
    private BigDecimal beta;

    /**
     * 胜率
     */
    private BigDecimal winRate;

    /**
     * 最近一月卡尔玛比率
     */
    private BigDecimal calmarRatio1m;

    /**
     * 最近三月卡尔玛比率
     */
    private BigDecimal calmarRatio3m;

    /**
     * 最近六月卡尔玛比率
     */
    private BigDecimal calmarRatio6m;

    /**
     * 最近一年卡尔玛比率
     */
    private BigDecimal calmarRatio1y;

    /**
     * 最近两年卡尔玛比率
     */
    private BigDecimal calmarRatio2y;

    /**
     * 最近三年卡尔玛比率
     */
    private BigDecimal calmarRatio3y;

    /**
     * 最近五年卡尔玛比率
     */
    private BigDecimal calmarRatio5y;

    /**
     * 成立以来卡尔玛比率
     */
    private BigDecimal calmarRatioIncep;

    /**
     * 今年以来卡尔玛比率
     */
    private BigDecimal calmarRatioYtd;

    /**
     * 最近一月索提诺比率
     */
    private BigDecimal sortinoRatio1m;

    /**
     * 最近三月索提诺比率
     */
    private BigDecimal sortinoRatio3m;

    /**
     * 最近六月索提诺比率
     */
    private BigDecimal sortinoRatio6m;

    /**
     * 最近一年索提诺比率
     */
    private BigDecimal sortinoRatio1y;

    /**
     * 最近两年索提诺比率
     */
    private BigDecimal sortinoRatio2y;

    /**
     * 最近三年索提诺比率
     */
    private BigDecimal sortinoRatio3y;

    /**
     * 最近五年索提诺比率
     */
    private BigDecimal sortinoRatio5y;

    /**
     * 成立以来索提诺比率
     */
    private BigDecimal sortinoRatioIncep;

    /**
     * 今年以来索提诺比率
     */
    private BigDecimal sortinoRatioYtd;

    /**
     * 最近一月alha
     */
    private BigDecimal alpha1m;

    /**
     * 最近三月alha
     */
    private BigDecimal alpha3m;

    /**
     * 最近六月alha
     */
    private BigDecimal alpha6m;

    /**
     * 最近一年alha
     */
    private BigDecimal alpha1y;

    /**
     * 最近两年alha
     */
    private BigDecimal alpha2y;

    /**
     * 最近三年alha
     */
    private BigDecimal alpha3y;

    /**
     * 最近五年alha
     */
    private BigDecimal alpha5y;

    /**
     * 成立以来alha
     */
    private BigDecimal alphaIncep;

    /**
     * 今年以来alha
     */
    private BigDecimal alphaYtd;

    /**
     * 最近一月beta
     */
    private BigDecimal beta1m;

    /**
     * 最近三月beta
     */
    private BigDecimal beta3m;

    /**
     * 最近六月beta
     */
    private BigDecimal beta6m;

    /**
     * 最近一年beta
     */
    private BigDecimal beta1y;

    /**
     * 最近两年beta
     */
    private BigDecimal beta2y;

    /**
     * 最近三年beta
     */
    private BigDecimal beta3y;

    /**
     * 最近五年beta
     */
    private BigDecimal beta5y;

    /**
     * 成立以来beta
     */
    private BigDecimal betaIncep;

    /**
     * 今年以来beta
     */
    private BigDecimal betaYtd;

    /**
     * 最近一月胜率
     */
    private BigDecimal winRate1m;

    /**
     * 最近三月胜率
     */
    private BigDecimal winRate3m;

    /**
     * 最近六月胜率
     */
    private BigDecimal winRate6m;

    /**
     * 最近一年胜率
     */
    private BigDecimal winRate1y;

    /**
     * 最近两年胜率
     */
    private BigDecimal winRate2y;

    /**
     * 最近三年胜率
     */
    private BigDecimal winRate3y;

    /**
     * 最近五年胜率
     */
    private BigDecimal winRate5y;

    /**
     * 成立以来胜率
     */
    private BigDecimal winRateIncep;

    /**
     * 今年以来胜率
     */
    private BigDecimal winRateYtd;

    /**
     * 最近一月下行标准差
     */
    private BigDecimal downsideRisk1m;

    /**
     * 最近三月下行标准差
     */
    private BigDecimal downsideRisk3m;

    /**
     * 最近六月下行标准差
     */
    private BigDecimal downsideRisk6m;

    /**
     * 最近一年下行标准差
     */
    private BigDecimal downsideRisk1y;

    /**
     * 最近两年下行标准差
     */
    private BigDecimal downsideRisk2y;

    /**
     * 最近三年下行标准差
     */
    private BigDecimal downsideRisk3y;

    /**
     * 最近五年下行标准差
     */
    private BigDecimal downsideRisk5y;

    /**
     * 成立以来下行标准差
     */
    private BigDecimal downsideRiskIncep;

    /**
     * 今年以来下行标准差
     */
    private BigDecimal downsideRiskYtd;

    /**
     * 最近一月信息比率
     */
    private BigDecimal informationalRatio1m;

    /**
     * 最近三月信息比率
     */
    private BigDecimal informationalRatio3m;

    /**
     * 最近六月信息比率
     */
    private BigDecimal informationalRatio6m;

    /**
     * 最近一年信息比率
     */
    private BigDecimal informationalRatio1y;

    /**
     * 最近两年信息比率
     */
    private BigDecimal informationalRatio2y;

    /**
     * 最近三年信息比率
     */
    private BigDecimal informationalRatio3y;

    /**
     * 最近五年信息比率
     */
    private BigDecimal informationalRatio5y;

    /**
     * 成立以来信息比率
     */
    private BigDecimal informationalRatioIncep;

    /**
     * 今年以来信息比率
     */
    private BigDecimal informationalRatioYtd;

    /**
     * 年度收益
     */
    private String annualRet;

    /**
     * 月度收益
     */
    private String monthlyRet;

    /**
     * 年度回撤
     */
    private String annualMaxdrawdown;
}